@@ -41,12 +41,12 @@ public:
     FractionRingWidget();
 
     /** destructor */
-    ~FractionRingWidget();
+    ~FractionRingWidget() override;
 
 protected:
     /** Function is called every time the screen need to be painted.
      **/
-    void paintEvent(QPaintEvent * event) Q_DECL_OVERRIDE;
+    void paintEvent(QPaintEvent * event) override;
 
     void resetFraction(bool update);
     bool checkTask();
